@@ -30,10 +30,3 @@ class DescribeRegionsRequest(RoaRequest):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-
-	def get_accept_language(self):
-		return self.get_query_params().get('accept_language')
-
-	def set_accept_language(self,accept_language):
-		self.add_query_param('accept_language',accept_language)
\ No newline at end of file
